/*
 * Copyright (C) 2011, Jamie Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef EVENTTYPES_EVENTFROMFILE_H
#define EVENTTYPES_EVENTFROMFILE_H

template <typename T1> class QSharedPointer;
template <typename T1> class QList;
template <typename T1, typename T2> class QPair;

namespace EventTypes
{
	class iEvent;

	typedef QPair<QSharedPointer<EventTypes::iEvent>, unsigned int> EventFromFile;
}

#endif // EVENTTYPES_EVENTFROMFILE_H
